using System;
using System.Collections.Generic;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Posts.WebApi.Helpers.Mappers;
using Posts.WebApi.Models.Enums;
using Posts.WebApi.Models.ModelDto;
using Posts.WebApi.Models.Requests;
using Posts.WebApi.Services;

namespace Posts.WebApi.Controllers
{
    [Route("/postsService/[controller]")]
    [ApiController]
    public class PostsController : BaseController
    {

        [HttpGet("test")]
        [Authorize]
        public async Task<ActionResult<IEnumerable<object>>> GetCountriesAsync()
         => Ok("yes");

        [HttpGet("test2")]
        public async Task<ActionResult<IEnumerable<object>>> GetCountriAsync()
  => Ok("yes");

        private readonly IServiceResultMapper _viewMapper;
        private readonly IPostService _postService;

        public PostsController(
            IServiceResultMapper viewMapper,
            IPostService postService)
        {
            _viewMapper = viewMapper;
            _postService = postService;
        }

        [HttpGet]
        [Authorize]
        public async Task<ActionResult<IEnumerable<PostShortDto>>> GetPostsAsync(int subjectId,
            string title = "", int groupId = 0, int? semester = 0, int? course = 0, EPostValueType? valueType = null,
            EPostLocationType? locationType = null,
            DateTimeOffset? givenDateFrom = null, DateTimeOffset? givenDateTo = null, int skip = 0, int take = 0)
            => _viewMapper.ServiceResultToContentResult(
                await _postService.GetPostsAsync(subjectId, UserId, title, groupId, semester, course, valueType, givenDateFrom,
                    givenDateTo, skip, take));

        [HttpGet("initial")]
        [Authorize]
        public async Task<ActionResult<IEnumerable<PostBySemesterGroupDto>>> GetInitialPostsAsync(int subjectId,
            string title = "", int groupId = 0, int? semester = 0, int? course = 0, EPostValueType? valueType = null,
            EPostLocationType? locationType = null,
            DateTimeOffset? givenDateFrom = null, DateTimeOffset? givenDateTo = null)
            => _viewMapper.ServiceResultToContentResult(
                await _postService.GetListOfInitialPostsAsync(subjectId, UserId, title, groupId, semester, course, valueType,
                    givenDateFrom, givenDateTo));

        [HttpGet("{id}")]
        [Authorize]
        public async Task<ActionResult<PostLongDto>> GetPostFullInfoAsync([FromRoute] string id)
            => _viewMapper.ServiceResultToContentResult(
                await _postService.GetPostFullInfoAsync(id, UserId, UserRole));

        [HttpPost]
        [Authorize]
        public async Task<ActionResult<PostLongDto>> AddPostAsync([FromBody] AddPostRequest request)
            => _viewMapper.ServiceResultToContentResult(
                await _postService.CreatePostAsync(request, UserId));

        [HttpDelete("{postId}")]
        [Authorize(Roles = nameof(ERoleType.Admin) + ", " + nameof(ERoleType.Student))]
        public async Task<ActionResult<PostLongDto>> Delete([FromRoute] string postId)
            => _viewMapper.ServiceResultToContentResult(
                await _postService.DeletePostAsync(postId, UserId, UserRole));

        [HttpPut("{postId}")]
        [Authorize(Roles = nameof(ERoleType.Admin) + ", " + nameof(ERoleType.Student))]
        public async Task<ActionResult<PostLongDto>> Update([FromBody] AddPostRequest request, [FromRoute] string postId)
            => _viewMapper.ServiceResultToContentResult(
                await _postService.UpdatePostAsync(request, postId, UserId));

        [HttpPatch("{postId}/validate")]
        [Authorize(Roles = nameof(ERoleType.Admin))]
        public async Task<ActionResult<PostLongDto>> Validate([FromRoute] string postId)
    => this._viewMapper.ServiceResultToContentResult(
        await this._postService.ValidatePostAsync(postId));

        [HttpGet("user")]
        [Authorize]
        public async Task<ActionResult<IEnumerable<PostProfileDto>>> GetMyPostsAsync(int skip = 0, int take = 0)
        => this._viewMapper.ServiceResultToContentResult(
                await this._postService.GetUsersPostsAsync(UserId, skip, take));
    }
}