import { NgModule } from '@angular/core';
import { Routes, RouterModule } from '@angular/router';

import { AuthComponent } from '@app/core/modules/authentication/components/authentication/auth.component';
import { RegisterComponent } from '@app/core/modules/authentication/components/registration/register.component';

import { AuthenticationGuard } from './core/modules/authentication/services/guards/authentication.guard';

const routes: Routes = [
  {
    path: 'authorization',
    component: AuthComponent,
  },
  {
    path: 'registration',
    component: RegisterComponent,
  },
  {
    path: 'profile',
    canActivate: [AuthenticationGuard],
    loadChildren: () => import('./modules/profile/profile.module').then(m => m.ProfileModule),
  },
  {
    path: 'select',
    canActivate: [AuthenticationGuard],
    loadChildren: () => import('./modules/search/search.module').then(m => m.SearchModule),
  },
  {
    path: 'post',
    loadChildren: () => import('./modules/post/post.module').then(m => m.PostModule),
  },
  {
    path: '**',
    redirectTo: 'authorization',
    pathMatch: 'full',
  },
];

@NgModule({
  imports: [RouterModule.forRoot(routes, { relativeLinkResolution: 'legacy' })],
  exports: [RouterModule],
})
export class AppRoutingModule {}
