import { NgModule } from '@angular/core';

import { JwtHelperService, JwtModule } from '@auth0/angular-jwt';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { AuthenticationModule} from './modules/authentication/authentication.module';
import { SharedModule } from '@shared/shared.module';

import {
  ValidationService,
  UniversityService,
  ProfileService,
  SelectSharedDataService,
  StorageService,
  FileService,
  HttpErrorHandlerService,
  PostService,
  GroupService,
  PopupService,
  UniversityWebServiceToken,
  UniversityRestService
} from '@services/index';

import { AuthenticationGuard } from './modules/authentication/services/guards/authentication.guard';
import { JwtInterceptor } from '@app/core/interceptors/jwt.interceptor';
import { HTTP_INTERCEPTORS } from '@angular/common/http';

export function jwtTokenGetter() {
  return localStorage.getItem('jwtToken');
}


@NgModule({
  declarations: [],
  imports: [
    BrowserAnimationsModule,
    SharedModule,
    AuthenticationModule,
    
    JwtModule.forRoot({
      config: {
        tokenGetter: jwtTokenGetter
      }
    })
  ],
  providers: [
    { provide: UniversityWebServiceToken, useClass: UniversityRestService},
    { provide: HTTP_INTERCEPTORS, useClass: JwtInterceptor, multi: true },
    UniversityRestService,

    ProfileService,
    SelectSharedDataService,
    ValidationService,
    StorageService,
    UniversityService,
    FileService,
    PostService,
    GroupService,
    HttpErrorHandlerService,
    JwtHelperService,
    PopupService,

    AuthenticationGuard
  ]
})
export class CoreModule { }
