import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

import { SharedModule} from '@shared/shared.module';

// Components
import { AuthComponent} from './components/authentication/auth.component';
import { RegisterComponent} from './components/registration/register.component';

// Services
import {
  AuthenticationWebServiceToken,
  AuthenticationRestService,
  AuthenticationService,
  UserProfileRestService
} from './services/web/index';

// Store
import { effects, reducers } from './model/store/index';
import { StoreModule } from '@ngrx/store';
import { EffectsModule } from '@ngrx/effects';

import { profilePersistantReducer} from './model/store/reducers/profile-persistant.reducer';

@NgModule({
  declarations: [
    AuthComponent,
    RegisterComponent,
  ],
  imports: [
    CommonModule,
    SharedModule,
    StoreModule.forFeature('authentication', reducers, { metaReducers: [profilePersistantReducer]}),
    EffectsModule.forFeature(effects)
  ],
  providers: [
    { provide: AuthenticationWebServiceToken, useClass: AuthenticationRestService},
    AuthenticationService,
    UserProfileRestService
  ]
})
export class AuthenticationModule { }
