import { Injectable } from '@angular/core';
import { Actions, Effect, ofType } from '@ngrx/effects';
import { switchMap, map, catchError } from 'rxjs/operators';
import { PostService } from '@app/core/services';

import * as postActions from './post.actions';
import { of } from 'rxjs';

@Injectable()
export class ProfileEffects {
  constructor(private actions$: Actions, private postService: PostService) {}

  @Effect()
  LoadPost$ = this.actions$.pipe(
    ofType(postActions.PostActionTypes.LoadPostStart),
    switchMap((action: postActions.LoadPostStart) => {
      return this.postService.getPostFullInfo(action.postId).pipe(
        map(fullPost => new postActions.LoadPostSuccess(fullPost)),
        catchError(response => of(new postActions.LoadPostFailure(response.error))),
      );
    }),
  );

  @Effect()
  ReportPost$ = this.actions$.pipe(
    ofType(postActions.PostActionTypes.ReportPostStart),
    switchMap((action: postActions.ReportPostStart) => {
      return this.postService.addComplaintForPost(action.postId, action.complain).pipe(
        map(() => new postActions.ReportPostSuccess()),
        catchError(response => of(new postActions.ReportPostFailure(response.error))),
      );
    }),
  );

  @Effect()
  DeletePost$ = this.actions$.pipe(
    ofType(postActions.PostActionTypes.DeletePostStart),
    switchMap((action: postActions.DeletePostStart) => {
      return this.postService.deletePost(action.postId).pipe(
        map(() => new postActions.DeletePostSuccess()),
        catchError(response => of(new postActions.DeletePostFailure(response.error))),
      );
    }),
  );

  @Effect()
  VerifyPost$ = this.actions$.pipe(
    ofType(postActions.PostActionTypes.VerifyPostStart),
    switchMap((action: postActions.VerifyPostStart) => {
      return this.postService.verifyPost(action.postId).pipe(
        map(() => new postActions.VerifyPostSuccess()),
        catchError(response => of(new postActions.VerifyPostFailure(response.error))),
      );
    }),
  );
}
