import { PostFull } from '@app/shared/models/post-full';
import * as postActions from './post.actions';

export interface PostState {
  post: PostFull | undefined;
  postId: string | undefined;
  loading: boolean;
  reloading: boolean;
  loaded: boolean;
  errorMessage: string | undefined;
}

export const initialState: PostState = {
  post: undefined,
  postId: undefined,
  loaded: false,
  loading: false,
  reloading: false,
  errorMessage: undefined,
};

export function reducer(state = initialState, action: postActions.PostActions): PostState {
  switch (action.type) {
    case postActions.PostActionTypes.LoadPostStart: {
      return {
        ...state,
        postId: action.postId,
        loading: true,
        errorMessage: undefined,
      };
    }
    case postActions.PostActionTypes.LoadPostSuccess: {
      return {
        ...state,
        post: action.postFull,
        loading: false,
        loaded: true,
      };
    }
    case postActions.PostActionTypes.LoadPostFailure: {
      return {
        ...state,
        loading: false,
        loaded: false,
        errorMessage: action.message,
      };
    }
    case postActions.PostActionTypes.ClearPost: {
      return initialState;
    }
    case postActions.PostActionTypes.ReportPostStart: {
      return {
        ...state,
        loading: true,
        errorMessage: undefined,
      };
    }
    case postActions.PostActionTypes.ReportPostSuccess: {
      return {
        ...state,
        loading: false,
        loaded: true,
      };
    }
    case postActions.PostActionTypes.ReportPostFailure: {
      return {
        ...state,
        loading: false,
        errorMessage: action.message,
      };
    }
    case postActions.PostActionTypes.DeletePostStart: {
      return {
        ...state,
        loading: true,
        errorMessage: undefined,
      };
    }
    case postActions.PostActionTypes.VerifyPostStart: {
      return {
        ...state,
        loading: true,
        errorMessage: undefined,
      };
    }
    case postActions.PostActionTypes.DeletePostSuccess: {
      return {
        ...state,
        loading: false,
        loaded: true,
      };
    }
    case postActions.PostActionTypes.DeletePostFailure: {
      return {
        ...state,
        loading: false,
        errorMessage: action.message,
      };
    }
    case postActions.PostActionTypes.VerifyPostSuccess: {
      return {
        ...state,
        loading: false,
        loaded: true,
      };
    }
    case postActions.PostActionTypes.VerifyPostFailure: {
      return {
        ...state,
        loading: false,
        errorMessage: action.message,
      };
    }
    default:
      return state;
  }
}
