import { Component, OnDestroy } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { UserProfile } from '@app/shared/models/user-profile.model';

import * as fromStore from '@core/modules/authentication/model/store/index';
import { Store } from '@ngrx/store';
import { UntilDestroy, untilDestroyed } from '@ngneat/until-destroy';

@UntilDestroy()
@Component({
  selector: 'app-profile-info',
  templateUrl: './profile-info.component.html',
  styleUrls: ['./profile-info.component.scss']
})
export class ProfileInfoComponent implements OnDestroy {

  public userProfile: UserProfile;
  public owner = false;

  constructor(private route: ActivatedRoute, private store: Store<fromStore.ProfileState>) {
    this.store.select(fromStore.getUserProfile).pipe(untilDestroyed(this)).subscribe(value => {
      if (value) {
        this.userProfile = value;
        const id = this.route.snapshot.paramMap.get('id')
        if (id != null) {
          this.owner = +id === this.userProfile.id;
        }
      }

    });
  }

  ngOnDestroy() {}
}
