import { Component, OnInit, ViewChild, ElementRef } from '@angular/core';
import { User } from '@app/shared/models';
import { UntypedFormGroup, UntypedFormControl, Validators, AbstractControl, UntypedFormBuilder } from '@angular/forms';

@Component({
  selector: 'app-settings',
  templateUrl: './settings.component.html',
  styleUrls: ['./settings.component.scss']
})
export class SettingsComponent implements OnInit {
  user: User;
  profileGroup: UntypedFormGroup;
  pwdGroup: UntypedFormGroup;
  emailControl: UntypedFormControl = new UntypedFormControl('', [Validators.required, Validators.email]);

  @ViewChild('fileInput')
  fileInput: ElementRef;

  constructor(public fb: UntypedFormBuilder) { }

  public uploadAvatar() {
    this.fileInput.nativeElement.click();
  }

  public ngOnInit() {
    this.profileGroup = this.fb.group({
      firstName: ['', Validators.required],
      lastName: ['', Validators.required]
    });

    this.pwdGroup = this.fb.group({
      currentPwd: ['', Validators.required],
      newPwd: ['', Validators.required],
      confirmPwd: ['', Validators.required],
    }, { validator: this.samePwdValidator });
  }


  public samePwdValidator(control: AbstractControl): { [key: string]: any } | null {
      const pwd: AbstractControl | null = control.get('newPwd');
      const confirm: AbstractControl | null = control.get('confirmPwd');
      return pwd && confirm && pwd.value === confirm.value ? null : { nomatch: true };
  }

}
