import { Component, OnInit, Input } from '@angular/core';
import { PostByGroupSemester } from '@app/shared/models/post-by-group-semester';
import { SelectSharedDataService } from '@app/core/services';
import { Post } from '@app/shared/models';
import { Router } from '@angular/router';
import { PostsService } from '@app/modules/search/services/web/posts.service';
import { MatDialog } from '@angular/material/dialog';

@Component({
  selector: 'app-post-select-card',
  templateUrl: './post-select-card.component.html',
  styleUrls: ['./post-select-card.component.scss'],
})
export class PostGroupedSelectCardComponent implements OnInit {
  @Input() postsByGroupSemester: PostByGroupSemester;
  public posts: Post[];
  public postsToShow: Post[];
  subjectId: number;
  isLoadMore: boolean;

  constructor(
    private selectPostService: PostsService,
    private selectSharedDataService: SelectSharedDataService,
    public router: Router,
    public dialog: MatDialog,
  ) {}

  public ngOnInit() {
    this.selectSharedDataService.subject.subscribe(subject => (this.subjectId = subject[0]));

    this.posts = this.postsByGroupSemester.posts;
    this.postsToShow = this.posts.slice(0, 3);
    this.isLoadMore = this.postsByGroupSemester.posts.length > 3;
  }

  public loadMore() {
    this.postsToShow = this.posts.slice(0, this.postsToShow.length + 10);

    this.selectPostService
      .getPosts(
        this.subjectId,
        this.postsByGroupSemester.groupId,
        this.postsByGroupSemester.semester,
        this.postsByGroupSemester.course,
        this.postsByGroupSemester.posts.length,
        10,
      )
      .subscribe((data: Post[]) => {
        for (let i = 0; i < data.length; i++) {
          this.posts.push(data[i]);
        }
        this.isLoadMore = this.posts.length > this.postsToShow.length;
      });
  }

  public navigateToPost(post: Post): void {
    this.router.navigate(['post/' + post.id]);
  }
}
