import { Action } from '@ngrx/store';
import { Subject } from '@app/shared/models/subject';

export enum SearchSubjectActionTypes {
  LoadSubjectsStart = '[SearchSubject] Load SearchSubjects',
  LoadSubjectsSuccess = '[SearchSubject] Load SearchSubjects Success',
  LoadSubjectsFailure = '[SearchSubject] Load SearchSubjects Failure',
  SelectSubject = '[SearchSubject] Select Subject',
  SetSubjectInitialState = '[SearchSubject] Set Subject Initial State',
}

export class LoadSubjectsStart implements Action {
  readonly type = SearchSubjectActionTypes.LoadSubjectsStart;
  constructor(public facultyId: number, public skip: number, public take: number) {}
}

export class LoadSubjectsSuccess implements Action {
  readonly type = SearchSubjectActionTypes.LoadSubjectsSuccess;
  constructor(public subjects: Subject[]) {}
}

export class LoadSubjectsFailure implements Action {
  readonly type = SearchSubjectActionTypes.LoadSubjectsFailure;
  constructor(public message: string) {}
}

export class SelectSubject implements Action {
  readonly type = SearchSubjectActionTypes.SelectSubject;
  constructor(public subject: Subject | undefined) {}
}

export class SetSubjectInitialState implements Action {
  readonly type = SearchSubjectActionTypes.SetSubjectInitialState;
}

export type SearchSubjectActions = LoadSubjectsStart | LoadSubjectsSuccess | LoadSubjectsFailure | SelectSubject | SetSubjectInitialState;
