import { Action } from '@ngrx/store';
import { University } from '@shared/models/university';

export enum SearchUniversityActionTypes {
  LoadUniversitiesStart = '[University] Load Universities Start',
  LoadUniversitiesSuccess = '[University] Load Universities Success',
  LoadUniversitiesFailure = '[University] Load Universities Failure',
  AddUniversity = '[University] Add University',
  ClearUniversities = '[University] Clear Universities',
  SelectUniversity = '[University] Select University',
  SetUniversityInitialState = '[University] Set University Initial State',
}

export class LoadUniversitiesStart implements Action {
  readonly type = SearchUniversityActionTypes.LoadUniversitiesStart;
  constructor(public cityId: number, public skip: number, public take?: number) {}
}

export class LoadUniversitiesSuccess implements Action {
  readonly type = SearchUniversityActionTypes.LoadUniversitiesSuccess;
  constructor(public universities: University[]) {}
}

export class LoadUniversitiesFailure implements Action {
  readonly type = SearchUniversityActionTypes.LoadUniversitiesFailure;
  constructor(public errorMessage: string) {}
}

export class ClearUniversities implements Action {
  readonly type = SearchUniversityActionTypes.ClearUniversities;
}

export class SelectUniversity implements Action {
  readonly type = SearchUniversityActionTypes.SelectUniversity;
  constructor(public university: University | undefined) {}
}

export class SetUniversityInitialState implements Action {
  readonly type = SearchUniversityActionTypes.SetUniversityInitialState;
}

export type UniversityActions =
  | LoadUniversitiesStart
  | LoadUniversitiesSuccess
  | LoadUniversitiesFailure
  | ClearUniversities
  | SelectUniversity
  | SetUniversityInitialState;
