import { Injectable } from '@angular/core';
import { Actions, Effect, ofType } from '@ngrx/effects';
import { Store } from '@ngrx/store';
import { filter, switchMap, tap, map, catchError } from 'rxjs/operators';
import { CityService } from '../../../services/web/city.service';
import * as fromUniversity from '../actions/';
import * as fromCity from '../actions/search-city.actions';
import { SearchUniversityState } from '../reducers/search-university.reducer';
import { of } from 'rxjs';

@Injectable()
export class CityEffects {
  constructor(private actions$: Actions, private cityService: CityService, private store: Store<SearchUniversityState>) {}

  @Effect()
  loadCity = this.actions$.pipe(
    ofType(fromCity.SearchCityActionTypes.LoadCityStart),
    switchMap((action: fromCity.LoadCityStart) => {
      return this.cityService.getCities(action.countryId).pipe(
        map(result => new fromCity.LoadCitySuccess(result)),
        catchError(message => of(new fromCity.LoadCityFailure(message))),
      );
    }),
  );

  @Effect()
  clearUniversities = this.actions$.pipe(
    ofType(fromCity.SearchCityActionTypes.SelectCity, fromCity.SearchCityActionTypes.SetSearchCityInitialState),
    tap((action: fromCity.SelectCity | fromCity.SetSearchCityInitialState) => {
      if (action instanceof fromCity.SetSearchCityInitialState || (action instanceof fromCity.SelectCity && action.City === undefined)) {
        this.store.dispatch(new fromUniversity.ClearUniversities());
      }
    }),
    filter(() => false),
  );
}
