import { Injectable } from '@angular/core';
import { Actions, Effect, ofType } from '@ngrx/effects';
import { UniversityService } from '@app/core/services';
import * as fromUniversity from '../actions/search-university.actions';
import * as fromFaculty from '../actions/search-faculty.actions';
import { switchMap, tap, filter } from 'rxjs/operators';
import { University } from '@app/shared/models/university';
import { Store } from '@ngrx/store';
import { SearchState } from '../reducers';

@Injectable()
export class UniversitiesEffects {
  @Effect()
  loadUniversity = this.actions$.pipe(
    ofType(fromUniversity.SearchUniversityActionTypes.LoadUniversitiesStart),
    switchMap(async (action: fromUniversity.LoadUniversitiesStart) => {
      try {
        const cities: University[] = await this.universityService.getUniversities(action.cityId, action.skip, action.take);
        return new fromUniversity.LoadUniversitiesSuccess(cities);
      } catch (error) {
        return new fromUniversity.LoadUniversitiesFailure(error);
      }
    }),
  );

  @Effect()
  selectUniversity = this.actions$.pipe(
    ofType(fromUniversity.SearchUniversityActionTypes.SelectUniversity),
    tap((action: fromUniversity.SelectUniversity) => {
      if (action.university) {
        this.store.dispatch(new fromFaculty.LoadFacultiesStart(action.university.id, 10, 0));
      }
    }),
    filter(() => false),
  );

  constructor(private actions$: Actions, private store: Store<SearchState>, private universityService: UniversityService) {}
}
