import * as fromCitySearch from '../actions/search-city.actions';
import { City } from '@shared/models/city';

export interface SearchCityState {
  cities: City[];
  selectedCity: City | undefined;
  loading: boolean;
  loaded: boolean;
  errorMessage: string | undefined;
}

export const initialCityState: SearchCityState = {
  cities: new Array<City>(),
  selectedCity: undefined,
  loading: false,
  loaded: false,
  errorMessage: undefined,
};

export function reducer(state = initialCityState, action: fromCitySearch.SearchCityAction): SearchCityState {
  switch (action.type) {
    case fromCitySearch.SearchCityActionTypes.LoadCityStart: {
      return {
        ...state,
        loading: true,
        loaded: false,
        errorMessage: undefined,
      };
    }
    case fromCitySearch.SearchCityActionTypes.LoadCitySuccess: {
      return {
        ...state,
        loading: false,
        loaded: true,
        cities: action.cities,
      };
    }
    case fromCitySearch.SearchCityActionTypes.LoadCityFailure: {
      return {
        ...state,
        loading: false,
        loaded: false,
        errorMessage: action.errorMessage,
      };
    }
    case fromCitySearch.SearchCityActionTypes.SelectCity: {
      return {
        ...state,
        selectedCity: action.City,
      };
    }
    case fromCitySearch.SearchCityActionTypes.SetSearchCityInitialState: {
      return initialCityState;
    }
    default:
      return state;
  }
}
