import * as fromCountrySearch from '../actions/search-country.actions';
import { Country } from '@shared/models/country';

export interface SearchCountryState {
  countries: Country[];
  selectedCountry: Country | undefined;
  loading: boolean;
  loaded: boolean;
  errorMessage: string | undefined;
}

export const initialCountryState: SearchCountryState = {
  countries: new Array<Country>(),
  selectedCountry: undefined,
  loading: false,
  loaded: false,
  errorMessage: undefined,
};

export function reducer(state = initialCountryState, action: fromCountrySearch.SearchCountryAction): SearchCountryState {
  switch (action.type) {
    case fromCountrySearch.SearchCountryActionTypes.LoadCountryStart: {
      return {
        ...state,
        loading: true,
        loaded: false,
        errorMessage: undefined,
      };
    }
    case fromCountrySearch.SearchCountryActionTypes.LoadCountrySuccess: {
      return {
        ...state,
        loading: false,
        loaded: true,
        countries: action.countries,
      };
    }
    case fromCountrySearch.SearchCountryActionTypes.LoadCountryFailure: {
      return {
        ...state,
        loading: false,
        loaded: false,
        errorMessage: action.errorMessage,
      };
    }
    case fromCountrySearch.SearchCountryActionTypes.SelectCountry: {
      return {
        ...state,
        selectedCountry: action.country,
      };
    }
    case fromCountrySearch.SearchCountryActionTypes.SetSearchCountryInitialState: {
      return initialCountryState;
    }
    default:
      return state;
  }
}
