import { EntityState, EntityAdapter, createEntityAdapter } from '@ngrx/entity';
import { University } from '@shared/models/university';
import { UniversityActions, SearchUniversityActionTypes } from '../actions/search-university.actions';

export interface SearchUniversityState extends EntityState<University> {
  selectedUniversity: University | undefined;
  loading: boolean;
  errorMessage: string | undefined;
}

export const adapter: EntityAdapter<University> = createEntityAdapter<University>();

export const initialState: SearchUniversityState = adapter.getInitialState({
  selectedUniversity: undefined,
  loading: false,
  errorMessage: undefined,
});

export function reducer(state = initialState, action: UniversityActions): SearchUniversityState {
  switch (action.type) {
    case SearchUniversityActionTypes.LoadUniversitiesStart: {
      return { ...state, loading: true, errorMessage: undefined };
    }
    case SearchUniversityActionTypes.LoadUniversitiesSuccess: {
      return adapter.addMany(action.universities, { ...state, loading: false });
    }
    case SearchUniversityActionTypes.LoadUniversitiesFailure: {
      return { ...state, loading: false, errorMessage: action.errorMessage };
    }
    case SearchUniversityActionTypes.ClearUniversities: {
      return adapter.removeAll(state);
    }
    case SearchUniversityActionTypes.SelectUniversity: {
      return { ...state, selectedUniversity: action.university };
    }
    case SearchUniversityActionTypes.SetUniversityInitialState:
      return initialState;
    default: {
      return state;
    }
  }
}

export const { selectIds, selectEntities, selectAll, selectTotal } = adapter.getSelectors();
