import { CanActivate, Router } from '@angular/router';
import { SearchState } from '../../model/store';
import { Store } from '@ngrx/store';
import * as fromGuardSelectors from '../../model/store/selectors/guard.selectors';

export abstract class SelectGuard implements CanActivate {
  protected isFacultyCanBeActivated: boolean;
  protected isSubjectCanBeActivated: boolean;
  protected isPostCanBeActivated: boolean;

  protected paths = {
    university: '/select/university',
    faculty: '/select/faculty',
    subject: '/select/subject',
    post: '/select/post',
  };

  constructor(protected state: Store<SearchState>, protected router: Router) {
    this.state.select(fromGuardSelectors.isFacultyCanBeSelected).subscribe(value => {
      this.isFacultyCanBeActivated = value;
    });
    this.state.select(fromGuardSelectors.isSubjectCanBeSelected).subscribe(value => {
      this.isSubjectCanBeActivated = value;
    });
    this.state.select(fromGuardSelectors.isPostCanBeSelected).subscribe(value => {
      this.isPostCanBeActivated = value;
    });
  }

  public abstract canActivate(): boolean;
}
