import { Component, OnInit, Input, EventEmitter, Output, OnDestroy } from '@angular/core';
import { UntypedFormControl } from '@angular/forms';
import { UntilDestroy, untilDestroyed } from '@ngneat/until-destroy';

@UntilDestroy()
@Component({
  selector: 'app-uni-select',
  templateUrl: './uni-select.component.html',
  styleUrls: ['./uni-select.component.css'],
})
export class UniSelectComponent<T> implements OnInit, OnDestroy {
  @Input() set selectedOption(value: T) {
    this.formControl.setValue(value, { emitEvent: false });
  }
  @Input() compareFunction: (obj: T, obj2: T) => boolean = (obj1: any, obj2: any) => obj1 === obj2;
  @Input() options: T[];
  @Input() displayWith: ((value: T | string) => string) | null = value => value as string;
  @Input() label: string | null = null;

  @Output() optionSelected = new EventEmitter<any>(); // Emit when options selected

  public formControl = new UntypedFormControl('');

  constructor() {}

  public ngOnInit() {
    this.formControl.valueChanges.pipe(untilDestroyed(this)).subscribe(val => this.optionSelected.emit(val));
  }

  public ngOnDestroy() {}
}
