using System.Security.Cryptography;
using Microsoft.AspNetCore.DataProtection;
using Newtonsoft.Json;
using Uni.WebApi.ApplicationCore.Helpers.Contract;

namespace Uni.WebApi.ApplicationCore.Helpers
{
    public class EncryptHelper : IEncryptHelper
    {
        private readonly IDataProtector _protector;

        public EncryptHelper(IDataProtectionProvider provider)
        {
            this._protector = provider.CreateProtector(GetType().FullName);
        }

        public string Encrypt<T>(T obj)
        {
            var json = JsonConvert.SerializeObject(obj);

            return Encrypt(json);
        }

        public string Encrypt(string plaintext)
        {
            return this._protector.Protect(plaintext);
        }

        public bool TryDecrypt<T>(string encryptedText, out T obj)
        {
            if (TryDecrypt(encryptedText, out var json))
            {
                obj = JsonConvert.DeserializeObject<T>(json);

                return true;
            }

            obj = default(T);

            return false;
        }

        public bool TryDecrypt(string encryptedText, out string decryptedText)
        {
            try
            {
                decryptedText = this._protector.Unprotect(encryptedText);

                return true;
            }
            catch (CryptographicException)
            {
                decryptedText = null;

                return false;
            }
        }
    }
}