using System.Collections.Generic;
using System.Threading.Tasks;
using AutoMapper;
using Uni.WebApi.ApplicationCore.Services.Contract;
using Uni.WebApi.DataAccess.RepositoryService;
using Uni.WebApi.Kernel.Entities;
using Uni.WebApi.Models.ModelDto;
using Uni.WebApi.Models.Models;
using Uni.WebApi.Models.Requests;

namespace Uni.WebApi.ApplicationCore.Services
{
    public class CityService : ICityService
    {
        private readonly IUnitOfWork _unitOfWork;
        private readonly IMapper _mapper;

        public CityService(
            IUnitOfWork unitOfWork,
            IMapper mapper)
        {
            this._mapper = mapper;
            this._unitOfWork = unitOfWork;
        }

        public async Task<ServiceResult<CityDto>> CreateCityAsync(AddCityRequest request)
           {
               if (!await this._unitOfWork.CountryRepository.IsExistById(request.CountryId))
               {
                   return ServiceResult<CityDto>.Fail(EOperationResult.EntityNotFound, "Country with this Id doesn't exist");
               }

               if (await this._unitOfWork.CityRepository.IsCityExistAsync(request.Title, request.CountryId))
               {
                   return ServiceResult<CityDto>.Fail(EOperationResult.AlreadyExist,
                       "City with this title already exist in this country");
               }

               var newCity = new City()
               {
                   Title = request.Title,
                   CountryId = request.CountryId
               };

               this._unitOfWork.CityRepository.Add(newCity);

               await this._unitOfWork.CommitAsync();

               return ServiceResult<CityDto>.Ok(this._mapper.Map<City, CityDto>(newCity));
           }

        public async Task<ServiceResult<IEnumerable<CityDto>>> GetListOfCitiesAsync(int countryId)
            {
                return ServiceResult<IEnumerable<CityDto>>.Ok(
                    this._mapper.Map<IEnumerable<City>, IEnumerable<CityDto>>(
                        await this._unitOfWork.CityRepository.GetCitiesByCountryAsync(countryId)));
            }
    }
}