using System.Collections.Generic;
using System.Threading.Tasks;
using AutoMapper;
using Uni.WebApi.ApplicationCore.Services.Contract;
using Uni.WebApi.DataAccess.RepositoryService;
using Uni.WebApi.Kernel.Entities;
using Uni.WebApi.Models.ModelDto;
using Uni.WebApi.Models.Models;

namespace Uni.WebApi.ApplicationCore.Services
{
    public class CountryService : ICountryService
    {
        private readonly IUnitOfWork _unitOfWork;
        private readonly IMapper _mapper;

        public CountryService(
            IUnitOfWork unitOfWork,
            IMapper mapper)
        {
            this._mapper = mapper;
            this._unitOfWork = unitOfWork;
        }

        public async Task<ServiceResult<CountryDto>> CreateCountryAsync(string countryTitle)
            {
                var newCountry = new Country()
                {
                    Title = countryTitle
                };

                this._unitOfWork.CountryRepository.Add(newCountry);

                await this._unitOfWork.CommitAsync();

                return ServiceResult<CountryDto>.Ok(this._mapper.Map<Country, CountryDto>(newCountry));
            }

        public async Task<ServiceResult<IEnumerable<CountryDto>>> GetListOfCountriesAsync()
            {
                return ServiceResult<IEnumerable<CountryDto>>.Ok(
                    this._mapper.Map<IEnumerable<Country>, IEnumerable<CountryDto>>(
                        await this._unitOfWork.CountryRepository.GetAllCountriesAsync()));
            }
    }
}