using System.Collections.Generic;
using System.Threading.Tasks;
using AutoMapper;
using Uni.WebApi.ApplicationCore.Helpers.Contract;
using Uni.WebApi.ApplicationCore.Services.Contract;
using Uni.WebApi.DataAccess.RepositoryService;
using Uni.WebApi.Kernel.Entities;
using Uni.WebApi.Models.ModelDto;
using Uni.WebApi.Models.Models;
using Uni.WebApi.Models.Requests;

namespace Uni.WebApi.ApplicationCore.Services
{
    public class GroupService : IGroupService
    {
        private readonly IUnitOfWork _unitOfWork;
        private readonly IMapper _mapper;
        private readonly IDateHelper _dateHelper;

        public GroupService(IUnitOfWork unitOfWork, IMapper mapper, IDateHelper dateHelper)
        {
            this._mapper = mapper;
            this._unitOfWork = unitOfWork;
            this._dateHelper = dateHelper;
        }
        
        public async Task<ServiceResult<GroupDto>> CreateGroupAsync(AddGroupRequest request)
        {
            if (!await this._unitOfWork.FacultyRepository.IsExistById(request.FacultyId))
            {
                return ServiceResult<GroupDto>.Fail(EOperationResult.EntityNotFound, "Faculty with this Id doesn't exist");
            }

            Group group = new Group()
            {
                Title = request.Title,
                YearStart = request.YearStart,
                FacultyId = request.FacultyId,
                CreatedAtUtc = this._dateHelper.GetDateTimeUtcNow(),
                ModifiedAtUtc = this._dateHelper.GetDateTimeUtcNow()
            };

            this._unitOfWork.GroupRepository.Add(group);
            await this._unitOfWork.CommitAsync();

            return ServiceResult<GroupDto>.Ok(this._mapper.Map<Group, GroupDto>(group));
        }

        public async Task<ServiceResult<IEnumerable<GroupDto>>> GetListOfGroupsAsync(int facultyId)
        {
            var allGroups = await this._unitOfWork.GroupRepository.GetGroupsByFacultyAsync(facultyId);
            var result = this._mapper.Map<IEnumerable<Group>, IEnumerable<GroupDto>>(allGroups);

            return ServiceResult<IEnumerable<GroupDto>>.Ok(result);
        }
    }
}