using System.Threading.Tasks;
using AutoMapper;
using Microsoft.Extensions.Options;
using Uni.WebApi.ApplicationCore.Helpers.Contract;
using Uni.WebApi.ApplicationCore.Services.Contract;
using Uni.WebApi.Common.Options;
using Uni.WebApi.DataAccess.RepositoryService;
using Uni.WebApi.Kernel.Entities;
using Uni.WebApi.Models.ModelDto;
using Uni.WebApi.Models.Models;
using Uni.WebApi.Models.Requests;

namespace Uni.WebApi.ApplicationCore.Services
{
    public class TeacherService : ITeacherService
    {
        private readonly IUnitOfWork _unitOfWork;
        private readonly IMapper _mapper;
        private readonly UrlsOptions _urlOptions;
        private readonly IDateHelper _dateHelper;

        public TeacherService(
            IUnitOfWork unitOfWork,
            IOptions<UrlsOptions> urlOptions,
            IMapper mapper,
            IDateHelper dateHelper)
        {
            this._mapper = mapper;
            this._unitOfWork = unitOfWork;
            this._urlOptions = urlOptions.Value;
            this._dateHelper = dateHelper;
        }

        public async Task<ServiceResult<TeacherDto>> CreateTeacherAsync(AddTeacherRequest request)
        {
            if (!await this._unitOfWork.UniversityRepository.IsExistById(request.UniversityId))
            {
                return ServiceResult<TeacherDto>.Fail(EOperationResult.EntityNotFound, "University with this Id doesn't exist");
            }
            
            var teacher = new Teacher()
            {
                CreatedAtUtc = this._dateHelper.GetDateTimeUtcNow(),
                ModifiedAtUtc = this._dateHelper.GetDateTimeUtcNow(),
                LastName = request.LastName,
                FirstName = request.FirstName,
                MiddleName = request.MiddleName,
                UniversityId = request.UniversityId
            };
            
            this._unitOfWork.TeacherRepository.Add(teacher);
            await this._unitOfWork.CommitAsync();

            return ServiceResult<TeacherDto>.Ok(this._mapper.Map<Teacher, TeacherDto>(teacher));
        }
    }
}