using System.Collections.Generic;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Uni.WebApi.ApplicationCore.Services.Contract;
using Uni.WebApi.Models.Enums;
using Uni.WebApi.Models.ModelDto;
using Uni.WebApi.Web.Helpers.Mappers;

namespace Uni.WebApi.Controllers
{
    [ApiVersion("1.0")]
    [Route("/v{api-version:apiVersion}/[controller]")]
    [ApiController]
    public class CountriesController : BaseController
    {
        private readonly IServiceResultMapper _viewMapper;
        private readonly ICountryService _countryService;

        public CountriesController(
            IServiceResultMapper viewMapper,
            ICountryService countryService)
        {
            this._viewMapper = viewMapper;
            this._countryService = countryService;
        }

        [HttpPost]
        [Authorize(Roles = nameof(ERoleType.Admin))]
        public async Task<ActionResult<CountryDto>> AddCountryAsync(string countryTitle)
            => this._viewMapper.ServiceResultToContentResult(
                await this._countryService.CreateCountryAsync(countryTitle));

        [HttpGet]
        public async Task<ActionResult<IEnumerable<CountryDto>>> GetCountriesAsync()
        => this._viewMapper.ServiceResultToContentResult(
                await this._countryService.GetListOfCountriesAsync());
    }
}
