using System.Threading.Tasks;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Uni.WebApi.ApplicationCore.Services.Contract;
using Uni.WebApi.Models.ModelDto;
using Uni.WebApi.Models.Requests.UserProfile;
using Uni.WebApi.Web.Helpers.Mappers;

namespace Uni.WebApi.Controllers
{
    [ApiVersion("1.0")]
    [Route("/v{api-version:apiVersion}/[controller]")]
    [ApiController]
    public class SettingsController : BaseController
    {
        private readonly IServiceResultMapper _viewMapper;
        private readonly IUserService _userService;

        public SettingsController(
            IServiceResultMapper viewMapper,
            IUserService userService)
        {
            this._viewMapper = viewMapper;
            this._userService = userService;
        }

        /// <summary>
        /// Update users information. If field isn't changed, leave it empty
        /// </summary>
        [HttpPut("Info")]
        [Authorize]
        public async Task<ActionResult<UserDto>> UpdateUserInfoAsync([FromBody] UpdateUserInfoRequest request)
            => this._viewMapper.ServiceResultToContentResult
                (await this._userService.UpdateUsersInfoAsync(UserId, request));

        /// <summary>
        /// Update users password
        /// </summary>
        [HttpPut("Password")]
        [Authorize]
        public async Task<ActionResult<UserDto>> UpdateUserPasswordAsync([FromBody] UpdatePasswordRequest request)
            => this._viewMapper.ServiceResultToContentResult
                (await this._userService.UpdatePasswordAsync(UserId, request));
    }
}