using System.Collections.Generic;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Uni.WebApi.ApplicationCore.Services.Contract;
using Uni.WebApi.Models.Enums;
using Uni.WebApi.Models.ModelDto;
using Uni.WebApi.Models.Requests;
using Uni.WebApi.Web.Helpers.Mappers;

namespace Uni.WebApi.Controllers
{
    [ApiVersion("1.0")]
    [Route("/v{api-version:apiVersion}/[controller]")]
    [ApiController]
    public class SubjectsController
    {
        private readonly IServiceResultMapper _viewMapper;
        private readonly ISubjectService _subjectService;

        public SubjectsController(
            IServiceResultMapper viewMapper,
            ISubjectService subjectService)
        {
            this._viewMapper = viewMapper;
            this._subjectService = subjectService;
        }
        
        [HttpPost]
        [Authorize(Roles = nameof(ERoleType.Admin))]
        public async Task<ActionResult<SubjectDto>> AddSubjectAsync([FromBody] AddSubjectRequest request)
            => this._viewMapper.ServiceResultToContentResult(
                await this._subjectService.CreateSubjectAsync(request));

        [HttpGet]
        public async Task<ActionResult<IEnumerable<SubjectDto>>> GetSubjectsAsync(int facultyId, int skip = 0, int take = 10)
        => this._viewMapper.ServiceResultToContentResult(
                await this._subjectService.GetListOfSubjectsAsync(facultyId, skip, take));
    }
}