using System.Collections.Generic;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Uni.WebApi.ApplicationCore.Services.Contract;
using Uni.WebApi.Models.Enums;
using Uni.WebApi.Models.ModelDto;
using Uni.WebApi.Models.Requests;
using Uni.WebApi.Web.Extensions;
using Uni.WebApi.Web.Helpers.Mappers;

namespace Uni.WebApi.Controllers
{
    [ApiVersion("1.0")]
    [Route("/v{api-version:apiVersion}/[controller]")]
    [ApiController]
    public class UniversitiesController : BaseController
    {
        private readonly IServiceResultMapper _viewMapper;
        private readonly IUniversityService _universityService;

        public UniversitiesController(
            IServiceResultMapper viewMapper,
            IUniversityService universityService)
        {
            this._viewMapper = viewMapper;
            this._universityService = universityService;
        }

        [HttpPost]
        [Authorize(Roles = nameof(ERoleType.Admin))]
        public async Task<ActionResult<UniversityDto>> AddUniversityAsync([FromBody] AddUniversityRequest request)
        {
            if (!ModelState.IsValid)
            {
                return BadRequest(ModelState.GetErrorMessages());
            }

            return this._viewMapper.ServiceResultToContentResult(await this._universityService.CreateUniversityAsync(request));
        }

        [HttpGet]
        public async Task<ActionResult<IEnumerable<UniversityDto>>> GetUniversitiesAsync(int cityId = 0, int skip = 0, int take = 10)
        => this._viewMapper.ServiceResultToContentResult(
                await this._universityService.GetListOfUniversitiesAsync(cityId, skip, take));
    }
}
