using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.EntityFrameworkCore;
using Uni.WebApi.DataAccess.RepositoryService.Interfaces;
using Uni.WebApi.Kernel.Entities;

namespace Uni.WebApi.DataAccess.RepositoryService.Repositories
{
    public class SubjectRepository : BaseRepository<Subject>, ISubjectRepository
    {
        public SubjectRepository(UniDbContext dbContext) : base(dbContext)
        {
        }

        public async Task<IEnumerable<Subject>> GetSubjectsByFacultyWithTeachersAsync(int facultyId, int skip, int take)
        {
            return await _dbContext.Subjects
                                   .Include(s => s.Teacher)
                                   .Where(s => s.FacultyId == facultyId)
                                   .OrderBy(s => s.Title)
                                   .Skip(skip).Take(take)
                                   .ToListAsync();
        }
    }
}