using System.Threading.Tasks;
using Uni.WebApi.DataAccess.RepositoryService.Interfaces;

namespace Uni.WebApi.DataAccess.RepositoryService
{
    public class UnitOfWork : IUnitOfWork
    {
        private readonly UniDbContext _dbContext;

        public IFacultyRepository FacultyRepository { get; }
        public IFileRepository FileRepository { get; }
        public ISubjectRepository SubjectRepository { get; }
        public IUniversityRepository UniversityRepository { get; }
        public IUserRepository UserRepository { get; }
        public ICountryRepository CountryRepository { get; }
        public ICityRepository CityRepository { get; }
        public ITeacherRepository TeacherRepository { get; }
        public IRefreshTokenRepository RefreshTokenRepository { get; }
        public IGroupRepository GroupRepository { get; }
        public UnitOfWork(UniDbContext dbContext,
                IFacultyRepository facultyRepository,
                IFileRepository fileRepository,
                IUniversityRepository universityRepository,
                ISubjectRepository subjectRepository,
                IUserRepository userRepository,
                ICountryRepository countryRepository,
                ICityRepository cityRepository,
                ITeacherRepository teacherRepository,
                IRefreshTokenRepository refreshTokenRepository,
                IGroupRepository groupRepository)
        {
            RefreshTokenRepository = refreshTokenRepository;
            FacultyRepository = facultyRepository;
            FileRepository = fileRepository;
            UniversityRepository = universityRepository;
            SubjectRepository = subjectRepository;
            UserRepository = userRepository;
            CountryRepository = countryRepository;
            CityRepository = cityRepository;
            TeacherRepository = teacherRepository;
            GroupRepository = groupRepository;

            this._dbContext = dbContext;
        }

        public async Task CommitAsync()
        {
            await this._dbContext.SaveChangesAsync();
        }
    }
}