﻿using System;
using System.Net;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using Newtonsoft.Json;
using Newtonsoft.Json.Serialization;
using Uni.WebApi.Kernel;

namespace Uni.WebApi.Web.Extensions
{
    public class ExceptionMiddleware
    {
        private readonly RequestDelegate _next;

        public ExceptionMiddleware(RequestDelegate next)
        {
            this._next = next ?? throw new ArgumentNullException(nameof(next));
        }

        public async Task Invoke(HttpContext context)
        {
            var nextContentResult =
                await GenerateContentResult<object>(async () => await this._next(context));

            if (nextContentResult.StatusCode != (int)HttpStatusCode.OK)
            {
                context.Response.Clear();

                context.Response.StatusCode = (int)HttpStatusCode.OK;
                context.Response.ContentType = "application/json";

                await context.Response.WriteAsync(JsonConvert.SerializeObject(nextContentResult));
            }
        }

        private static async Task<ContentResult> GenerateContentResult<T>(Func<Task> func)
            where T : class
        {
            ContentResult contentResult = null;

            T result = null;

            try
            {
                await func();
            }
            catch (StatusException se)
            {
                contentResult = new ContentResult();
                contentResult.ContentType = "text/plain";
                contentResult.Content = se.Message;
                contentResult.StatusCode = (int)HttpStatusCode.BadRequest;
            }

            if (contentResult == null)
            {
                contentResult = new ContentResult();
                contentResult.ContentType = "application/json";
                
                var serializerSettings = new JsonSerializerSettings
                                         {
                                             ContractResolver = new CamelCasePropertyNamesContractResolver()
                                         };
                contentResult.Content = JsonConvert.SerializeObject(null, serializerSettings);
                contentResult.StatusCode = (int)HttpStatusCode.OK;
            }

            return contentResult;
        }
    }
}